Class: Aws::BCMPricingCalculator::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BCMPricingCalculator::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bcmpricingcalculator/client.rb,
sig/client.rbs
Overview
An API client for BCMPricingCalculator. To construct a client, you need to configure a :region and :credentials.
client = Aws::BCMPricingCalculator::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchCreateBillScenarioCommitmentModificationResponseSuccess, _BatchCreateBillScenarioUsageModificationResponseSuccess, _BatchCreateWorkloadEstimateUsageResponseSuccess, _BatchDeleteBillScenarioCommitmentModificationResponseSuccess, _BatchDeleteBillScenarioUsageModificationResponseSuccess, _BatchDeleteWorkloadEstimateUsageResponseSuccess, _BatchUpdateBillScenarioCommitmentModificationResponseSuccess, _BatchUpdateBillScenarioUsageModificationResponseSuccess, _BatchUpdateWorkloadEstimateUsageResponseSuccess, _CreateBillEstimateResponseSuccess, _CreateBillScenarioResponseSuccess, _CreateWorkloadEstimateResponseSuccess, _DeleteBillEstimateResponseSuccess, _DeleteBillScenarioResponseSuccess, _DeleteWorkloadEstimateResponseSuccess, _GetBillEstimateResponseSuccess, _GetBillScenarioResponseSuccess, _GetPreferencesResponseSuccess, _GetWorkloadEstimateResponseSuccess, _ListBillEstimateCommitmentsResponseSuccess, _ListBillEstimateInputCommitmentModificationsResponseSuccess, _ListBillEstimateInputUsageModificationsResponseSuccess, _ListBillEstimateLineItemsResponseSuccess, _ListBillEstimatesResponseSuccess, _ListBillScenarioCommitmentModificationsResponseSuccess, _ListBillScenarioUsageModificationsResponseSuccess, _ListBillScenariosResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkloadEstimateUsageResponseSuccess, _ListWorkloadEstimatesResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateBillEstimateResponseSuccess, _UpdateBillScenarioResponseSuccess, _UpdatePreferencesResponseSuccess, _UpdateWorkloadEstimateResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchCreateBillScenarioCommitmentModificationResponse
Create Compute Savings Plans, EC2 Instance Savings Plans, or EC2 Reserved Instances commitments that you want to model in a Bill Scenario.
-
#batch_create_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchCreateBillScenarioUsageModificationResponse
Create Amazon Web Services service usage that you want to model in a Bill Scenario.
-
#batch_create_workload_estimate_usage(params = {}) ⇒ Types::BatchCreateWorkloadEstimateUsageResponse
Create Amazon Web Services service usage that you want to model in a Workload Estimate.
-
#batch_delete_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioCommitmentModificationResponse
Delete commitment that you have created in a Bill Scenario.
-
#batch_delete_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioUsageModificationResponse
Delete usage that you have created in a Bill Scenario.
-
#batch_delete_workload_estimate_usage(params = {}) ⇒ Types::BatchDeleteWorkloadEstimateUsageResponse
Delete usage that you have created in a Workload estimate.
-
#batch_update_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioCommitmentModificationResponse
Update a newly added or existing commitment.
-
#batch_update_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioUsageModificationResponse
Update a newly added or existing usage lines.
-
#batch_update_workload_estimate_usage(params = {}) ⇒ Types::BatchUpdateWorkloadEstimateUsageResponse
Update a newly added or existing usage lines.
-
#create_bill_estimate(params = {}) ⇒ Types::CreateBillEstimateResponse
Create a Bill estimate from a Bill scenario.
-
#create_bill_scenario(params = {}) ⇒ Types::CreateBillScenarioResponse
Creates a new bill scenario to model potential changes to Amazon Web Services usage and costs.
-
#create_workload_estimate(params = {}) ⇒ Types::CreateWorkloadEstimateResponse
Creates a new workload estimate to model costs for a specific workload.
-
#delete_bill_estimate(params = {}) ⇒ Struct
Deletes an existing bill estimate.
-
#delete_bill_scenario(params = {}) ⇒ Struct
Deletes an existing bill scenario.
-
#delete_workload_estimate(params = {}) ⇒ Struct
Deletes an existing workload estimate.
-
#get_bill_estimate(params = {}) ⇒ Types::GetBillEstimateResponse
Retrieves details of a specific bill estimate.
-
#get_bill_scenario(params = {}) ⇒ Types::GetBillScenarioResponse
Retrieves details of a specific bill scenario.
-
#get_preferences(params = {}) ⇒ Types::GetPreferencesResponse
Retrieves the current preferences for Pricing Calculator.
-
#get_workload_estimate(params = {}) ⇒ Types::GetWorkloadEstimateResponse
Retrieves details of a specific workload estimate.
-
#list_bill_estimate_commitments(params = {}) ⇒ Types::ListBillEstimateCommitmentsResponse
Lists the commitments associated with a bill estimate.
-
#list_bill_estimate_input_commitment_modifications(params = {}) ⇒ Types::ListBillEstimateInputCommitmentModificationsResponse
Lists the input commitment modifications associated with a bill estimate.
-
#list_bill_estimate_input_usage_modifications(params = {}) ⇒ Types::ListBillEstimateInputUsageModificationsResponse
Lists the input usage modifications associated with a bill estimate.
-
#list_bill_estimate_line_items(params = {}) ⇒ Types::ListBillEstimateLineItemsResponse
Lists the line items associated with a bill estimate.
-
#list_bill_estimates(params = {}) ⇒ Types::ListBillEstimatesResponse
Lists all bill estimates for the account.
-
#list_bill_scenario_commitment_modifications(params = {}) ⇒ Types::ListBillScenarioCommitmentModificationsResponse
Lists the commitment modifications associated with a bill scenario.
-
#list_bill_scenario_usage_modifications(params = {}) ⇒ Types::ListBillScenarioUsageModificationsResponse
Lists the usage modifications associated with a bill scenario.
-
#list_bill_scenarios(params = {}) ⇒ Types::ListBillScenariosResponse
Lists all bill scenarios for the account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a specified resource.
-
#list_workload_estimate_usage(params = {}) ⇒ Types::ListWorkloadEstimateUsageResponse
Lists the usage associated with a workload estimate.
-
#list_workload_estimates(params = {}) ⇒ Types::ListWorkloadEstimatesResponse
Lists all workload estimates for the account.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_bill_estimate(params = {}) ⇒ Types::UpdateBillEstimateResponse
Updates an existing bill estimate.
-
#update_bill_scenario(params = {}) ⇒ Types::UpdateBillScenarioResponse
Updates an existing bill scenario.
-
#update_preferences(params = {}) ⇒ Types::UpdatePreferencesResponse
Updates the preferences for Pricing Calculator.
-
#update_workload_estimate(params = {}) ⇒ Types::UpdateWorkloadEstimateResponse
Updates an existing workload estimate.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2796 2797 2798 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2796 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2799 2800 2801 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2799 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_create_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchCreateBillScenarioCommitmentModificationResponse
Create Compute Savings Plans, EC2 Instance Savings Plans, or EC2 Reserved Instances commitments that you want to model in a Bill Scenario.
BatchCreateBillScenarioCommitmentModification operation doesn't
have its own IAM permission. To authorize this operation for Amazon
Web Services principals, include the permission
bcm-pricing-calculator:CreateBillScenarioCommitmentModification in
your policies.
88 |
# File 'sig/client.rbs', line 88
def batch_create_bill_scenario_commitment_modification: (
|
#batch_create_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchCreateBillScenarioUsageModificationResponse
Create Amazon Web Services service usage that you want to model in a Bill Scenario.
BatchCreateBillScenarioUsageModification operation doesn't have
its own IAM permission. To authorize this operation for Amazon Web
Services principals, include the permission
bcm-pricing-calculator:CreateBillScenarioUsageModification in your
policies.
123 |
# File 'sig/client.rbs', line 123
def batch_create_bill_scenario_usage_modification: (
|
#batch_create_workload_estimate_usage(params = {}) ⇒ Types::BatchCreateWorkloadEstimateUsageResponse
Create Amazon Web Services service usage that you want to model in a Workload Estimate.
BatchCreateWorkloadEstimateUsage operation doesn't have its own
IAM permission. To authorize this operation for Amazon Web Services
principals, include the permission
bcm-pricing-calculator:CreateWorkloadEstimateUsage in your policies.
153 |
# File 'sig/client.rbs', line 153
def batch_create_workload_estimate_usage: (
|
#batch_delete_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioCommitmentModificationResponse
Delete commitment that you have created in a Bill Scenario. You can only delete a commitment that you had added and cannot model deletion (or removal) of a existing commitment. If you want model deletion of an existing commitment, see the negate BillScenarioCommitmentModificationAction of BatchCreateBillScenarioCommitmentModification operation.
BatchDeleteBillScenarioCommitmentModification operation doesn't
have its own IAM permission. To authorize this operation for Amazon
Web Services principals, include the permission
bcm-pricing-calculator:DeleteBillScenarioCommitmentModification in
your policies.
176 |
# File 'sig/client.rbs', line 176
def batch_delete_bill_scenario_commitment_modification: (
|
#batch_delete_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioUsageModificationResponse
Delete usage that you have created in a Bill Scenario. You can only delete usage that you had added and cannot model deletion (or removal) of a existing usage. If you want model removal of an existing usage, see BatchUpdateBillScenarioUsageModification.
BatchDeleteBillScenarioUsageModification operation doesn't have
its own IAM permission. To authorize this operation for Amazon Web
Services principals, include the permission
bcm-pricing-calculator:DeleteBillScenarioUsageModification in your
policies.
187 |
# File 'sig/client.rbs', line 187
def batch_delete_bill_scenario_usage_modification: (
|
#batch_delete_workload_estimate_usage(params = {}) ⇒ Types::BatchDeleteWorkloadEstimateUsageResponse
Delete usage that you have created in a Workload estimate. You can only delete usage that you had added and cannot model deletion (or removal) of a existing usage. If you want model removal of an existing usage, see BatchUpdateWorkloadEstimateUsage.
BatchDeleteWorkloadEstimateUsage operation doesn't have its own
IAM permission. To authorize this operation for Amazon Web Services
principals, include the permission
bcm-pricing-calculator:DeleteWorkloadEstimateUsage in your policies.
198 |
# File 'sig/client.rbs', line 198
def batch_delete_workload_estimate_usage: (
|
#batch_update_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioCommitmentModificationResponse
Update a newly added or existing commitment. You can update the commitment group based on a commitment ID and a Bill scenario ID.
BatchUpdateBillScenarioCommitmentModification operation doesn't
have its own IAM permission. To authorize this operation for Amazon
Web Services principals, include the permission
bcm-pricing-calculator:UpdateBillScenarioCommitmentModification in
your policies.
210 |
# File 'sig/client.rbs', line 210
def batch_update_bill_scenario_commitment_modification: (
|
#batch_update_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioUsageModificationResponse
Update a newly added or existing usage lines. You can update the usage amounts, usage hour, and usage group based on a usage ID and a Bill scenario ID.
BatchUpdateBillScenarioUsageModification operation doesn't have
its own IAM permission. To authorize this operation for Amazon Web
Services principals, include the permission
bcm-pricing-calculator:UpdateBillScenarioUsageModification in your
policies.
227 |
# File 'sig/client.rbs', line 227
def batch_update_bill_scenario_usage_modification: (
|
#batch_update_workload_estimate_usage(params = {}) ⇒ Types::BatchUpdateWorkloadEstimateUsageResponse
Update a newly added or existing usage lines. You can update the usage amounts and usage group based on a usage ID and a Workload estimate ID.
BatchUpdateWorkloadEstimateUsage operation doesn't have its own
IAM permission. To authorize this operation for Amazon Web Services
principals, include the permission
bcm-pricing-calculator:UpdateWorkloadEstimateUsage in your policies.
250 |
# File 'sig/client.rbs', line 250
def batch_update_workload_estimate_usage: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2769 2770 2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2769 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BCMPricingCalculator') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bcmpricingcalculator' context[:gem_version] = '1.30.0' Seahorse::Client::Request.new(handlers, context) end |
#create_bill_estimate(params = {}) ⇒ Types::CreateBillEstimateResponse
Create a Bill estimate from a Bill scenario. In the Bill scenario you can model usage addition, usage changes, and usage removal. You can also model commitment addition and commitment removal. After all changes in a Bill scenario is made satisfactorily, you can call this API with a Bill scenario ID to generate the Bill estimate. Bill estimate calculates the pre-tax cost for your consolidated billing family, incorporating all modeled usage and commitments alongside existing usage and commitments from your most recent completed anniversary bill, with any applicable discounts applied.
277 |
# File 'sig/client.rbs', line 277
def create_bill_estimate: (
|
#create_bill_scenario(params = {}) ⇒ Types::CreateBillScenarioResponse
Creates a new bill scenario to model potential changes to Amazon Web Services usage and costs.
298 |
# File 'sig/client.rbs', line 298
def create_bill_scenario: (
|
#create_workload_estimate(params = {}) ⇒ Types::CreateWorkloadEstimateResponse
Creates a new workload estimate to model costs for a specific workload.
321 |
# File 'sig/client.rbs', line 321
def create_workload_estimate: (
|
#delete_bill_estimate(params = {}) ⇒ Struct
Deletes an existing bill estimate.
333 |
# File 'sig/client.rbs', line 333
def delete_bill_estimate: (
|
#delete_bill_scenario(params = {}) ⇒ Struct
Deletes an existing bill scenario.
342 |
# File 'sig/client.rbs', line 342
def delete_bill_scenario: (
|
#delete_workload_estimate(params = {}) ⇒ Struct
Deletes an existing workload estimate.
351 |
# File 'sig/client.rbs', line 351
def delete_workload_estimate: (
|
#get_bill_estimate(params = {}) ⇒ Types::GetBillEstimateResponse
Retrieves details of a specific bill estimate.
371 |
# File 'sig/client.rbs', line 371
def get_bill_estimate: (
|
#get_bill_scenario(params = {}) ⇒ Types::GetBillScenarioResponse
Retrieves details of a specific bill scenario.
389 |
# File 'sig/client.rbs', line 389
def get_bill_scenario: (
|
#get_preferences(params = {}) ⇒ Types::GetPreferencesResponse
Retrieves the current preferences for Pricing Calculator.
401 |
# File 'sig/client.rbs', line 401
def get_preferences: (
|
#get_workload_estimate(params = {}) ⇒ Types::GetWorkloadEstimateResponse
Retrieves details of a specific workload estimate.
419 |
# File 'sig/client.rbs', line 419
def get_workload_estimate: (
|
#list_bill_estimate_commitments(params = {}) ⇒ Types::ListBillEstimateCommitmentsResponse
Lists the commitments associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
430 |
# File 'sig/client.rbs', line 430
def list_bill_estimate_commitments: (
|
#list_bill_estimate_input_commitment_modifications(params = {}) ⇒ Types::ListBillEstimateInputCommitmentModificationsResponse
Lists the input commitment modifications associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
443 |
# File 'sig/client.rbs', line 443
def list_bill_estimate_input_commitment_modifications: (
|
#list_bill_estimate_input_usage_modifications(params = {}) ⇒ Types::ListBillEstimateInputUsageModificationsResponse
Lists the input usage modifications associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
456 |
# File 'sig/client.rbs', line 456
def list_bill_estimate_input_usage_modifications: (
|
#list_bill_estimate_line_items(params = {}) ⇒ Types::ListBillEstimateLineItemsResponse
Lists the line items associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
476 |
# File 'sig/client.rbs', line 476
def list_bill_estimate_line_items: (
|
#list_bill_estimates(params = {}) ⇒ Types::ListBillEstimatesResponse
Lists all bill estimates for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
496 |
# File 'sig/client.rbs', line 496
def list_bill_estimates: (
|
#list_bill_scenario_commitment_modifications(params = {}) ⇒ Types::ListBillScenarioCommitmentModificationsResponse
Lists the commitment modifications associated with a bill scenario.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
523 |
# File 'sig/client.rbs', line 523
def list_bill_scenario_commitment_modifications: (
|
#list_bill_scenario_usage_modifications(params = {}) ⇒ Types::ListBillScenarioUsageModificationsResponse
Lists the usage modifications associated with a bill scenario.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
536 |
# File 'sig/client.rbs', line 536
def list_bill_scenario_usage_modifications: (
|
#list_bill_scenarios(params = {}) ⇒ Types::ListBillScenariosResponse
Lists all bill scenarios for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
556 |
# File 'sig/client.rbs', line 556
def list_bill_scenarios: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a specified resource.
582 |
# File 'sig/client.rbs', line 582
def list_tags_for_resource: (
|
#list_workload_estimate_usage(params = {}) ⇒ Types::ListWorkloadEstimateUsageResponse
Lists the usage associated with a workload estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
593 |
# File 'sig/client.rbs', line 593
def list_workload_estimate_usage: (
|
#list_workload_estimates(params = {}) ⇒ Types::ListWorkloadEstimatesResponse
Lists all workload estimates for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
613 |
# File 'sig/client.rbs', line 613
def list_workload_estimates: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
638 |
# File 'sig/client.rbs', line 638
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
648 |
# File 'sig/client.rbs', line 648
def untag_resource: (
|
#update_bill_estimate(params = {}) ⇒ Types::UpdateBillEstimateResponse
Updates an existing bill estimate.
669 |
# File 'sig/client.rbs', line 669
def update_bill_estimate: (
|
#update_bill_scenario(params = {}) ⇒ Types::UpdateBillScenarioResponse
Updates an existing bill scenario.
689 |
# File 'sig/client.rbs', line 689
def update_bill_scenario: (
|
#update_preferences(params = {}) ⇒ Types::UpdatePreferencesResponse
Updates the preferences for Pricing Calculator.
705 |
# File 'sig/client.rbs', line 705
def update_preferences: (
|
#update_workload_estimate(params = {}) ⇒ Types::UpdateWorkloadEstimateResponse
Updates an existing workload estimate.
726 |
# File 'sig/client.rbs', line 726
def update_workload_estimate: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2789 2790 2791 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2789 def waiter_names [] end |