Class: Aws::BCMPricingCalculator::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BCMPricingCalculator::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bcmpricingcalculator/client.rb
Overview
An API client for BCMPricingCalculator. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BCMPricingCalculator::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchCreateBillScenarioCommitmentModificationResponse
Create Compute Savings Plans, EC2 Instance Savings Plans, or EC2 Reserved Instances commitments that you want to model in a Bill Scenario.
-
#batch_create_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchCreateBillScenarioUsageModificationResponse
Create Amazon Web Services service usage that you want to model in a Bill Scenario.
-
#batch_create_workload_estimate_usage(params = {}) ⇒ Types::BatchCreateWorkloadEstimateUsageResponse
Create Amazon Web Services service usage that you want to model in a Workload Estimate.
-
#batch_delete_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioCommitmentModificationResponse
Delete commitment that you have created in a Bill Scenario.
-
#batch_delete_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioUsageModificationResponse
Delete usage that you have created in a Bill Scenario.
-
#batch_delete_workload_estimate_usage(params = {}) ⇒ Types::BatchDeleteWorkloadEstimateUsageResponse
Delete usage that you have created in a Workload estimate.
-
#batch_update_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioCommitmentModificationResponse
Update a newly added or existing commitment.
-
#batch_update_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioUsageModificationResponse
Update a newly added or existing usage lines.
-
#batch_update_workload_estimate_usage(params = {}) ⇒ Types::BatchUpdateWorkloadEstimateUsageResponse
Update a newly added or existing usage lines.
-
#create_bill_estimate(params = {}) ⇒ Types::CreateBillEstimateResponse
Create a Bill estimate from a Bill scenario.
-
#create_bill_scenario(params = {}) ⇒ Types::CreateBillScenarioResponse
Creates a new bill scenario to model potential changes to Amazon Web Services usage and costs.
-
#create_workload_estimate(params = {}) ⇒ Types::CreateWorkloadEstimateResponse
Creates a new workload estimate to model costs for a specific workload.
-
#delete_bill_estimate(params = {}) ⇒ Struct
Deletes an existing bill estimate.
-
#delete_bill_scenario(params = {}) ⇒ Struct
Deletes an existing bill scenario.
-
#delete_workload_estimate(params = {}) ⇒ Struct
Deletes an existing workload estimate.
-
#get_bill_estimate(params = {}) ⇒ Types::GetBillEstimateResponse
Retrieves details of a specific bill estimate.
-
#get_bill_scenario(params = {}) ⇒ Types::GetBillScenarioResponse
Retrieves details of a specific bill scenario.
-
#get_preferences(params = {}) ⇒ Types::GetPreferencesResponse
Retrieves the current preferences for Pricing Calculator.
-
#get_workload_estimate(params = {}) ⇒ Types::GetWorkloadEstimateResponse
Retrieves details of a specific workload estimate.
-
#list_bill_estimate_commitments(params = {}) ⇒ Types::ListBillEstimateCommitmentsResponse
Lists the commitments associated with a bill estimate.
-
#list_bill_estimate_input_commitment_modifications(params = {}) ⇒ Types::ListBillEstimateInputCommitmentModificationsResponse
Lists the input commitment modifications associated with a bill estimate.
-
#list_bill_estimate_input_usage_modifications(params = {}) ⇒ Types::ListBillEstimateInputUsageModificationsResponse
Lists the input usage modifications associated with a bill estimate.
-
#list_bill_estimate_line_items(params = {}) ⇒ Types::ListBillEstimateLineItemsResponse
Lists the line items associated with a bill estimate.
-
#list_bill_estimates(params = {}) ⇒ Types::ListBillEstimatesResponse
Lists all bill estimates for the account.
-
#list_bill_scenario_commitment_modifications(params = {}) ⇒ Types::ListBillScenarioCommitmentModificationsResponse
Lists the commitment modifications associated with a bill scenario.
-
#list_bill_scenario_usage_modifications(params = {}) ⇒ Types::ListBillScenarioUsageModificationsResponse
Lists the usage modifications associated with a bill scenario.
-
#list_bill_scenarios(params = {}) ⇒ Types::ListBillScenariosResponse
Lists all bill scenarios for the account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a specified resource.
-
#list_workload_estimate_usage(params = {}) ⇒ Types::ListWorkloadEstimateUsageResponse
Lists the usage associated with a workload estimate.
-
#list_workload_estimates(params = {}) ⇒ Types::ListWorkloadEstimatesResponse
Lists all workload estimates for the account.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_bill_estimate(params = {}) ⇒ Types::UpdateBillEstimateResponse
Updates an existing bill estimate.
-
#update_bill_scenario(params = {}) ⇒ Types::UpdateBillScenarioResponse
Updates an existing bill scenario.
-
#update_preferences(params = {}) ⇒ Types::UpdatePreferencesResponse
Updates the preferences for Pricing Calculator.
-
#update_workload_estimate(params = {}) ⇒ Types::UpdateWorkloadEstimateResponse
Updates an existing workload estimate.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2796 2797 2798 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2796 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2799 2800 2801 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2799 def errors_module Errors end |
Instance Method Details
#batch_create_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchCreateBillScenarioCommitmentModificationResponse
Create Compute Savings Plans, EC2 Instance Savings Plans, or EC2 Reserved Instances commitments that you want to model in a Bill Scenario.
<note markdown=“1”> The ‘BatchCreateBillScenarioCommitmentModification` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:CreateBillScenarioCommitmentModification` in your policies.
</note>
567 568 569 570 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 567 def batch_create_bill_scenario_commitment_modification(params = {}, = {}) req = build_request(:batch_create_bill_scenario_commitment_modification, params) req.send_request() end |
#batch_create_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchCreateBillScenarioUsageModificationResponse
Create Amazon Web Services service usage that you want to model in a Bill Scenario.
<note markdown=“1”> The ‘BatchCreateBillScenarioUsageModification` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:CreateBillScenarioUsageModification` in your policies.
</note>
719 720 721 722 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 719 def batch_create_bill_scenario_usage_modification(params = {}, = {}) req = build_request(:batch_create_bill_scenario_usage_modification, params) req.send_request() end |
#batch_create_workload_estimate_usage(params = {}) ⇒ Types::BatchCreateWorkloadEstimateUsageResponse
Create Amazon Web Services service usage that you want to model in a Workload Estimate.
<note markdown=“1”> The ‘BatchCreateWorkloadEstimateUsage` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:CreateWorkloadEstimateUsage` in your policies.
</note>
864 865 866 867 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 864 def batch_create_workload_estimate_usage(params = {}, = {}) req = build_request(:batch_create_workload_estimate_usage, params) req.send_request() end |
#batch_delete_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioCommitmentModificationResponse
Delete commitment that you have created in a Bill Scenario. You can only delete a commitment that you had added and cannot model deletion (or removal) of a existing commitment. If you want model deletion of an existing commitment, see the negate [ BillScenarioCommitmentModificationAction] of [ BatchCreateBillScenarioCommitmentModification] operation.
<note markdown=“1”> The ‘BatchDeleteBillScenarioCommitmentModification` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:DeleteBillScenarioCommitmentModification` in your policies.
</note>
[1]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_AWSBCMPricingCalculator_BillScenarioCommitmentModificationAction.html [2]: docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_AWSBCMPricingCalculator_BatchCreateBillScenarioUsageModification.html
918 919 920 921 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 918 def batch_delete_bill_scenario_commitment_modification(params = {}, = {}) req = build_request(:batch_delete_bill_scenario_commitment_modification, params) req.send_request() end |
#batch_delete_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchDeleteBillScenarioUsageModificationResponse
Delete usage that you have created in a Bill Scenario. You can only delete usage that you had added and cannot model deletion (or removal) of a existing usage. If you want model removal of an existing usage, see [ BatchUpdateBillScenarioUsageModification].
<note markdown=“1”> The ‘BatchDeleteBillScenarioUsageModification` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:DeleteBillScenarioUsageModification` in your policies.
</note>
969 970 971 972 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 969 def batch_delete_bill_scenario_usage_modification(params = {}, = {}) req = build_request(:batch_delete_bill_scenario_usage_modification, params) req.send_request() end |
#batch_delete_workload_estimate_usage(params = {}) ⇒ Types::BatchDeleteWorkloadEstimateUsageResponse
Delete usage that you have created in a Workload estimate. You can only delete usage that you had added and cannot model deletion (or removal) of a existing usage. If you want model removal of an existing usage, see [ BatchUpdateWorkloadEstimateUsage].
<note markdown=“1”> The ‘BatchDeleteWorkloadEstimateUsage` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:DeleteWorkloadEstimateUsage` in your policies.
</note>
1019 1020 1021 1022 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1019 def batch_delete_workload_estimate_usage(params = {}, = {}) req = build_request(:batch_delete_workload_estimate_usage, params) req.send_request() end |
#batch_update_bill_scenario_commitment_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioCommitmentModificationResponse
Update a newly added or existing commitment. You can update the commitment group based on a commitment ID and a Bill scenario ID.
<note markdown=“1”> The ‘BatchUpdateBillScenarioCommitmentModification` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:UpdateBillScenarioCommitmentModification` in your policies.
</note>
1080 1081 1082 1083 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1080 def batch_update_bill_scenario_commitment_modification(params = {}, = {}) req = build_request(:batch_update_bill_scenario_commitment_modification, params) req.send_request() end |
#batch_update_bill_scenario_usage_modification(params = {}) ⇒ Types::BatchUpdateBillScenarioUsageModificationResponse
Update a newly added or existing usage lines. You can update the usage amounts, usage hour, and usage group based on a usage ID and a Bill scenario ID.
<note markdown=“1”> The ‘BatchUpdateBillScenarioUsageModification` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:UpdateBillScenarioUsageModification` in your policies.
</note>
1179 1180 1181 1182 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1179 def batch_update_bill_scenario_usage_modification(params = {}, = {}) req = build_request(:batch_update_bill_scenario_usage_modification, params) req.send_request() end |
#batch_update_workload_estimate_usage(params = {}) ⇒ Types::BatchUpdateWorkloadEstimateUsageResponse
Update a newly added or existing usage lines. You can update the usage amounts and usage group based on a usage ID and a Workload estimate ID.
<note markdown=“1”> The ‘BatchUpdateWorkloadEstimateUsage` operation doesn’t have its own IAM permission. To authorize this operation for Amazon Web Services principals, include the permission ‘bcm-pricing-calculator:UpdateWorkloadEstimateUsage` in your policies.
</note>
1272 1273 1274 1275 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1272 def batch_update_workload_estimate_usage(params = {}, = {}) req = build_request(:batch_update_workload_estimate_usage, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2769 2770 2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2769 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BCMPricingCalculator') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bcmpricingcalculator' context[:gem_version] = '1.28.0' Seahorse::Client::Request.new(handlers, context) end |
#create_bill_estimate(params = {}) ⇒ Types::CreateBillEstimateResponse
Create a Bill estimate from a Bill scenario. In the Bill scenario you can model usage addition, usage changes, and usage removal. You can also model commitment addition and commitment removal. After all changes in a Bill scenario is made satisfactorily, you can call this API with a Bill scenario ID to generate the Bill estimate. Bill estimate calculates the pre-tax cost for your consolidated billing family, incorporating all modeled usage and commitments alongside existing usage and commitments from your most recent completed anniversary bill, with any applicable discounts applied.
1379 1380 1381 1382 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1379 def create_bill_estimate(params = {}, = {}) req = build_request(:create_bill_estimate, params) req.send_request() end |
#create_bill_scenario(params = {}) ⇒ Types::CreateBillScenarioResponse
Creates a new bill scenario to model potential changes to Amazon Web Services usage and costs.
1449 1450 1451 1452 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1449 def create_bill_scenario(params = {}, = {}) req = build_request(:create_bill_scenario, params) req.send_request() end |
#create_workload_estimate(params = {}) ⇒ Types::CreateWorkloadEstimateResponse
Creates a new workload estimate to model costs for a specific workload.
1514 1515 1516 1517 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1514 def create_workload_estimate(params = {}, = {}) req = build_request(:create_workload_estimate, params) req.send_request() end |
#delete_bill_estimate(params = {}) ⇒ Struct
Deletes an existing bill estimate.
1536 1537 1538 1539 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1536 def delete_bill_estimate(params = {}, = {}) req = build_request(:delete_bill_estimate, params) req.send_request() end |
#delete_bill_scenario(params = {}) ⇒ Struct
Deletes an existing bill scenario.
1558 1559 1560 1561 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1558 def delete_bill_scenario(params = {}, = {}) req = build_request(:delete_bill_scenario, params) req.send_request() end |
#delete_workload_estimate(params = {}) ⇒ Struct
Deletes an existing workload estimate.
1580 1581 1582 1583 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1580 def delete_workload_estimate(params = {}, = {}) req = build_request(:delete_workload_estimate, params) req.send_request() end |
#get_bill_estimate(params = {}) ⇒ Types::GetBillEstimateResponse
Retrieves details of a specific bill estimate.
1637 1638 1639 1640 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1637 def get_bill_estimate(params = {}, = {}) req = build_request(:get_bill_estimate, params) req.send_request() end |
#get_bill_scenario(params = {}) ⇒ Types::GetBillScenarioResponse
Retrieves details of a specific bill scenario.
1682 1683 1684 1685 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1682 def get_bill_scenario(params = {}, = {}) req = build_request(:get_bill_scenario, params) req.send_request() end |
#get_preferences(params = {}) ⇒ Types::GetPreferencesResponse
Retrieves the current preferences for Pricing Calculator.
1708 1709 1710 1711 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1708 def get_preferences(params = {}, = {}) req = build_request(:get_preferences, params) req.send_request() end |
#get_workload_estimate(params = {}) ⇒ Types::GetWorkloadEstimateResponse
Retrieves details of a specific workload estimate.
1754 1755 1756 1757 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1754 def get_workload_estimate(params = {}, = {}) req = build_request(:get_workload_estimate, params) req.send_request() end |
#list_bill_estimate_commitments(params = {}) ⇒ Types::ListBillEstimateCommitmentsResponse
Lists the commitments associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1805 1806 1807 1808 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1805 def list_bill_estimate_commitments(params = {}, = {}) req = build_request(:list_bill_estimate_commitments, params) req.send_request() end |
#list_bill_estimate_input_commitment_modifications(params = {}) ⇒ Types::ListBillEstimateInputCommitmentModificationsResponse
Lists the input commitment modifications associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1856 1857 1858 1859 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1856 def list_bill_estimate_input_commitment_modifications(params = {}, = {}) req = build_request(:list_bill_estimate_input_commitment_modifications, params) req.send_request() end |
#list_bill_estimate_input_usage_modifications(params = {}) ⇒ Types::ListBillEstimateInputUsageModificationsResponse
Lists the input usage modifications associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1946 1947 1948 1949 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 1946 def list_bill_estimate_input_usage_modifications(params = {}, = {}) req = build_request(:list_bill_estimate_input_usage_modifications, params) req.send_request() end |
#list_bill_estimate_line_items(params = {}) ⇒ Types::ListBillEstimateLineItemsResponse
Lists the line items associated with a bill estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2016 2017 2018 2019 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2016 def list_bill_estimate_line_items(params = {}, = {}) req = build_request(:list_bill_estimate_line_items, params) req.send_request() end |
#list_bill_estimates(params = {}) ⇒ Types::ListBillEstimatesResponse
Lists all bill estimates for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2083 2084 2085 2086 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2083 def list_bill_estimates(params = {}, = {}) req = build_request(:list_bill_estimates, params) req.send_request() end |
#list_bill_scenario_commitment_modifications(params = {}) ⇒ Types::ListBillScenarioCommitmentModificationsResponse
Lists the commitment modifications associated with a bill scenario.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2133 2134 2135 2136 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2133 def list_bill_scenario_commitment_modifications(params = {}, = {}) req = build_request(:list_bill_scenario_commitment_modifications, params) req.send_request() end |
#list_bill_scenario_usage_modifications(params = {}) ⇒ Types::ListBillScenarioUsageModificationsResponse
Lists the usage modifications associated with a bill scenario.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2223 2224 2225 2226 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2223 def list_bill_scenario_usage_modifications(params = {}, = {}) req = build_request(:list_bill_scenario_usage_modifications, params) req.send_request() end |
#list_bill_scenarios(params = {}) ⇒ Types::ListBillScenariosResponse
Lists all bill scenarios for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2293 2294 2295 2296 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2293 def list_bill_scenarios(params = {}, = {}) req = build_request(:list_bill_scenarios, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a specified resource.
2322 2323 2324 2325 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2322 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workload_estimate_usage(params = {}) ⇒ Types::ListWorkloadEstimateUsageResponse
Lists the usage associated with a workload estimate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2411 2412 2413 2414 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2411 def list_workload_estimate_usage(params = {}, = {}) req = build_request(:list_workload_estimate_usage, params) req.send_request() end |
#list_workload_estimates(params = {}) ⇒ Types::ListWorkloadEstimatesResponse
Lists all workload estimates for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2481 2482 2483 2484 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2481 def list_workload_estimates(params = {}, = {}) req = build_request(:list_workload_estimates, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
2509 2510 2511 2512 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2509 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
2535 2536 2537 2538 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2535 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_bill_estimate(params = {}) ⇒ Types::UpdateBillEstimateResponse
Updates an existing bill estimate.
2600 2601 2602 2603 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2600 def update_bill_estimate(params = {}, = {}) req = build_request(:update_bill_estimate, params) req.send_request() end |
#update_bill_scenario(params = {}) ⇒ Types::UpdateBillScenarioResponse
Updates an existing bill scenario.
2663 2664 2665 2666 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2663 def update_bill_scenario(params = {}, = {}) req = build_request(:update_bill_scenario, params) req.send_request() end |
#update_preferences(params = {}) ⇒ Types::UpdatePreferencesResponse
Updates the preferences for Pricing Calculator.
2706 2707 2708 2709 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2706 def update_preferences(params = {}, = {}) req = build_request(:update_preferences, params) req.send_request() end |
#update_workload_estimate(params = {}) ⇒ Types::UpdateWorkloadEstimateResponse
Updates an existing workload estimate.
2760 2761 2762 2763 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2760 def update_workload_estimate(params = {}, = {}) req = build_request(:update_workload_estimate, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2789 2790 2791 |
# File 'lib/aws-sdk-bcmpricingcalculator/client.rb', line 2789 def waiter_names [] end |